
%macro calcPred(useData=);
	data _null_;
  		dsid=open("&useData");
		call symput('chkID', 	varnum(dsid, 'id'));
  		call symput('chkAge', 	varnum(dsid,'age'));
		call symput('chkEthnicity',	varnum(dsid,'ethnicity'));
		call symput('chkHt', 	varnum(dsid,'ht'));
		call symput('chkWt', 	varnum(dsid,'wt'));
		call symput('chkArml', 	varnum(dsid,'arml'));
		call symput('chkLeg', 	varnum(dsid,'leg'));
		call symput('chkArmc', 	varnum(dsid,'armc'));
		call symput('chkWaist', varnum(dsid,'waist'));
		call symput('chkCalf', 	varnum(dsid,'calf'));
		call symput('chkThic', 	varnum(dsid,'thic'));
		call symput('chkTri', 	varnum(dsid,'tri'));
		call symput('chkSub', 	varnum(dsid,'sub'));
		call symput('chkMenses',varnum(dsid,'menses'));
	run;


		%if &chkID=0 | &chkAge=0 | &chkEthnicity=0 | &chkHt=0 | &chkWt=0 | &chkArml=0 | &chkLeg=0 | &chkArmc=0 |
			&chkWaist=0 | &chkCalf=0 | &chkThic=0 | &chkTri=0 | &chkSub=0 | (&chkMenses=0 and %upcase(sex)=F)
			%then %do; %let stopExe=1; %end;
			%else %do; %let stopExe=0;
		%end;




	%if &stopExe=1 %then %do;
		%put ERROR: Dataset error, predicted body fat was not calculated. ;

		%if &chkID=0 %then %put ERROR: Variable ID does not exist. ;
		%if &chkAge=0 	%then %put ERROR: Variable AGE does not exist. ;
		%if &chkEthnicity=0	%then %put ERROR: Variable ETHNICITY does not exist. ;
		%if &chkHt=0 	%then %put ERROR: Variable HT does not exist. ;
		%if &chkWt=0 	%then %put ERROR: Variable WT does not exist. ;
		%if &chkArml=0 	%then %put ERROR: Variable ARML does not exist. ;
		%if &chkLeg=0 	%then %put ERROR: Variable LEG does not exist. ;
		%if &chkArmc=0 	%then %put ERROR: Variable ARMC does not exist. ;
		%if &chkWaist=0 %then %put ERROR: Variable WAIST does not exist. ;
		%if &chkCalf=0 	%then %put ERROR: Variable CALF does not exist. ;
		%if &chkThic=0 	%then %put ERROR: Variable THIC does not exist. ;
		%if &chkTri=0 	%then %put ERROR: Variable TRI does not exist. ;
		%if &chkSub=0 	%then %put ERROR: Variable SUB does not exist. ;
		%if &chkMenses=0 and %upcase(sex)=F %then %put ERROR: Variable MENSES does not exist. ;

	%goto exit;
	%end;

	%if &chkEthnicity ^=0 | &chkMenses ^=0 %then %do;
		data makedata;
			set &usedata(keep=
				%if &chkMenses ^=0 %then %do; menses %end;
				%if &chkEthnicity ^=0 %then %do; ethnicity %end;);
			%if &chkMenses ^=0 %then %do;
				chkMensesUnit=(menses in (0, 1));
			%end;
			%if &chkEthnicity ^=0 %then %do;
				chkEthnicityUnit=(upcase(ethnicity) in ("W", "B", "M", "O"));
			%end;
		run;

		proc sql noprint;
			select 
				%if &chkMenses ^=0 and &chkEthnicity ^=0 %then %do;
					min(chkMensesUnit), min(chkEthnicityUnit) into :chkMensesUnit, :chkEthnicityUnit
				%end;
					%else %if &chkMenses ^=0 %then %do;
						min(chkMensesUnit) into :chkMensesUnit
					%end;
					%else %if &chkEthnicity ^=0 %then %do;
						min(chkEthnicityUnit) into :chkEthnicityUnit
					%end;
				%end;
				from makedata;
		quit;

	data coefMod;
		set macrolib.ABCC_Anthro_Data;
	run;


	proc sort data=&usedata; by id; run;

	****Body Fat Prediction****;
	*********
	*Model A;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModA(drop=_name_ _label_) prefix=_MA;
	    id parameter;
	    var MModA;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModA(drop=_name_ _label_) prefix=_FA;
	    id parameter;
	    var FModA;
	run;
	*Merge "A" data sets;
	proc sql;
		create table coefModA2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML, t.LEG, t.MENSES,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModA as m, coefFModA as f, &usedata as t;
	quit;

	**Delete temporary data sets**;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODA COEFFMODA;
	RUN;

	*Calculate Predicted body fat;
	data coefModA;
		set coefModA2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 
				predBF_A =
					_MAintercept +
					_MAadage2Rwaist3R	* (adult* (age**(-2))* waist**(-3) )+
					_MAadage3Rleg3R		* (adult* (age**(-3))* (leg**(-3)) )+
					_MAadage3Rwaist3R 	* (adult* (age**(-3))* waist**(-3) )+ 
					_MAadage3leg3R    	* (adult* (age**3)* (leg**(-3)) )+
					_MAadage3tri		* (adult* (age**3)* tri )+
					_MAadageRtri3R  	* (adult* (age**(-1))* (tri**(-3)) )+
					_MAadagecalf3R    	* (adult*age* (calf**(-3)) )+
					_MAadageht3   		* (adult*age* (ht**3) )+
					_MAadagewt2       	* (adult*age* (wt**2) )+
					_MAadht3    		* (adult* (ht**3) )+
					_MAadtri3    		* (adult* (tri**3) )+
					_MAadtri3R   		* (adult* (tri**(-3)) )+
					_MAadwaist2			* (adult* (waist**2) )+
					_MAadwt2    		* (adult* (wt**2) )+
					_MAage3Rleg3R  		* ((age**(-3))* (leg**(-3)) )+
					_MAage3Rtri3    	* ((age**(-3))* (tri**3) )+
					_MAageRsub     		* ((age**(-1))* sub )+
					_MAageRtri    		* ((age**(-1))* tri )+
					_MAageRwt2   		* ((age**(-1))* (wt**2) )+
					_MAagecalf3R   		* (age* (calf**(-3)) )+
					_MAagesub3			* (age* (sub**3) )+
					_MAagewaist3R     	* (age* (waist**(-3)) )+    
					_MAarmc     		* (armc )+
					_MAarmc2      		* (armc**2 )+
					_MAarmc3R     		* (armc**(-3) )+
					_MAarml2      		* (arml**2 )+
					_MAbkadtri3       	* (bk*adult* (tri**3) )+
					_MAbkarmc3			* (bk* (armc**3) )+
					_MAbkarml3R    		* (bk* (arml**(-3)) )+
					_MAbkwt3R         	* (bk* (wt**(-3)) )+
					_MAht     			* (ht )+
					_MAmtadthic3R   	* (mt*adult* (thic**(-3)) )+
					_MAmtadtri    		* (mt*adult* tri )+
					_MAmxadwt3   		* (mx*adult* (wt**3) )+
					_MAmxtri3R   		* (mx* (tri**(-3)) )+
					_MAmxwt2R			* (mx* (wt**(-2)) )+
					_MAmxwt3        	* (mx* (wt**3) )+
					_MAsub3         	* (sub**3 )+
					_MAsubR      		* (sub**(-1) )+
					_MAthic3R     		* (thic**(-3) )+
					_MAtri       		* (tri )+
					_MAtriR      		* (tri**(-1) )+
					_MAwaist			* (waist )
					
				;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 
			predBF_A = 
						_FAintercept +
						_FABMI			* (BMI)+
						_FAadage3Rsub2 	* (adult * (age**(-3)) * (sub**2) )+ 
						_FAadage3Rtri3R	* (adult * (age**(-3)) * (tri**(-3)) )+ 
						_FAadage3sub3  	* (adult * (age**3) * (sub**3 ) )+
						_FAadage3sub3R 	* (adult * (age**3) * (sub**(-3)) )+  
						_FAadage3subR		* (adult * (age**3) * (sub**(-1)) )+ 
						_FAadage3tri3		* (adult * (age**3) * (tri**3) )+ 
						_FAadbmi3R		* (adult * (bmi**(-3)) )+  
						_FAage2Rsub2 		* ((age**(-2)) * (sub**2) )+
						_FAage2Rtri2  	* ((age**(-2)) * (tri**2) )+
						_FAage2thic 		* ((age**2) * (thic) )+
						_FAage2thic2 		* ((age**2) * (thic**2) )+
						_FAage3Rleg3R 	* ((age**(-3)) * (leg**(-3)) )+
						_FAage3sub3R		* ((age**3) * (sub**(-3)) )+
						_FAageRsub2  		* ((age**(-1)) * (sub**2) )+
						_FAageRtri2  		* ((age**(-1)) * (tri**2) )+
						_FAagecalf3R   	* (age * (calf**(-3)) )+
						_FAagethic2   	* (age * (thic**2) )+
						_FAarml3R  		* (arml**(-3) )+
						_FAbkadthic3R     * (bk*adult* (thic**(-3)) )+
						_FAbkht3   		* (bk* (ht**3) )+
						_FAbkleg3R		* (bk* (leg**(-3)) )+
						_FAbkthicR    	* (bk* (thic**(-1)) )+
						_FAbmiR    		* (bmi**(-1) )+
						_FAcalf3R     	* (calf**(-3) )+
						_FAht        		* (ht )+
						_FAht2      		* (ht**2 )+
						_FAleg3R   		* (leg**(-3) )+
						_FAmenswaist3R   	* (menses * (waist**(-3)) )+
						_FAmtadsub3		* (mt*adult* (sub**3) )+
						_FAmxarml3R    	* (mx* (arml**(-3)) )+
						_FAmxcalf3R      	* (mx* (calf**(-3)) )+
						_FAsubR       	* (sub**(-1) )+
						_FAtri       		* (tri )+
						_FAtriR       	* (tri**(-1) )+
						_FAwaist      	* (waist )+
						_FAwaistR			* (waist**(-1) )
						
				;
	run;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODA2;
	RUN;

	proc sql;
		create table MOD1 as
		select a.predbf_a, a.ID
		from coefModA as a;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODA;
	RUN;

	PROC SORT DATA=MOD1;
		BY ID;
	RUN;

	*********
	*Model B;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModB(drop=_name_ _label_) prefix=_MB;
	    id parameter;
	    var MModB;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModB(drop=_name_ _label_) prefix=_FB;
	    id parameter;
	    var FModB;
	run;
	*Merge "B" data sets;
	proc sql;
		create table coefModB2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML, t.LEG, t.MENSES,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModB as m, coefFModB as f, &usedata as t;
	quit;

	**Delete temporary datasets**;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODB COEFFMODB; 
	RUN;
	
	*Calculate Predicted body fat;
	data coefModB;
		set coefModB2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBF_B= 
						_MBintercept +
						_MBadage2Rwaist3R	* (adult* (age**(-2))* (waist**(-3)) )+
						_MBadage3Rwaist3R 	* (adult* (age**(-3))* (waist**(-3)) )+
						_MBadage3tri   		* (adult* (age**3)* tri )+
						_MBadageRtri3R  	* (adult* (age**(-1))* (tri**(-3)) )+
						_MBadageht3  		* (adult*age* (ht**3) )+
						_MBadagewaist2		* (adult*age* (waist**2) )+
						_MBadagewt2   		* (adult*age* (wt**2) )+
						_MBadtri3R   		* (adult* (tri**(-3)) )+
						_MBage2Rsub   		* ((age**(-2))* sub )+
						_MBage3Rtri3   		* ((age**(-3))* (tri**3) )+
						_MBageRarmc3    	* ((age**(-1))* (armc**3) )+
						_MBageRsub      	* ((age**(-1))* sub )+
						_MBageRtri     		* ((age**(-1))* tri )+
						_MBageRwt2			* ((age**(-1))* wt**2 )+
						_MBagecalf3R      	* (age* (calf**(-3)) )+
						_MBagesub3   		* (age* (sub**3) )+
						_MBagewaist3R     	* (age* (waist**(-3)) )+
						_MBarmc      		* (armc )+
						_MBarmc2      		* (armc**2 )+
						_MBarmc3R     		* (armc**(-3) )+
						_MBbkarmc3			* (bk* armc**3 )+
						_MBbkwaist2R      	* (bk* waist**(-2) )+
						_MBht       		* (ht )+
						_MBhtR     			* (ht**(-1) )+
						_MBmtadthic3R   	* (mt*adult* thic**(-3) )+
						_MBmtadtri   		* (mt*adult* tri )+
						_MBmxcalf3R   		* (mx* calf**(-3) )+
						_MBmxtri3R   		* (mx* tri**(-3) )+
						_MBmxwt2R			* (mx* wt**(-2) )+
						_MBmxwt3      		* (mx* wt**3 )+
						_MBsubR      		* (sub**(-1) )+
						_MBthic3R         	* (thic**(-3) )+
						_MBtri        		* (tri )+
						_MBtriR      		* (tri**(-1) )+
						_MBwaist			* (waist )
						
					;
				

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")  then 

				predBF_B=	
							_FBintercept +
							_FBBMI			* (bmi )+
							_FBadage2ht3  	* (adult* (age**2)* (ht**3) )+
							_FBadage2thic  	* (adult* (age**2)* thic )+
							_FBadage3Rsub2  	* (adult* (age**(-3))* (sub**2) )+
							_FBadage3Rsub3R  	* (adult* (age**(-3))* (sub**(-3)) )+
							_FBadage3Rthic3	* (adult* (age**(-3))* (thic**3) )+
							_FBadage3Rtri3R  	* (adult* (age**(-3))* (tri**(-3)) )+
							_FBadage3sub3  	* (adult* (age**3)* (sub**3) )+
							_FBadage3tri3  	* (adult* (age**3)* (tri**3) )+
							_FBadage3tri3R   	* (adult* (age**3)* (tri**(-3)) )+
							_FBadbmi3R  		* (adult* (bmi**(-3)) )+
							_FBage2Rbmi3  	* ((age**(-2))* (bmi**3) )+
							_FBage2Rtri2		* ((age**(-2))* (tri**2) )+
							_FBage2thic  		* ((age**2)* thic )+
							_FBage3Rbmi3R  	* ((age**(-3))* (bmi**(-3)) )+
							_FBage3sub3R    	* ((age**3)* (sub**(-3)) )+
							_FBageRsub    	* ((age**(-1))* sub )+
							_FBageRtri3R    	* ((age**(-1))* (tri**(-3)) )+
							_FBagethic2  		* (age* (thic**2) )+
							_FBbkadthic3R   	* (bk*adult* (thic**(-3)) )+
							_FBbkadtri3		* (bk*adult* (tri**3) )+
							_FBbkarmc3    	* (bk* (armc**3) )+
							_FBbkcalf3R   	* (bk* (calf**(-3)) )+
							_FBbkthicR    	* (bk* (thic**(-1)) )+
							_FBbktriR    		* (bk* (tri**(-1)) )+
							_FBbkwaist      	* (bk* waist )+
							_FBbmiR    		* (bmi**(-1) )+
							_FBcalf2R    		* (calf**(-2) )+
							_FBcalf3R			* (calf**(-3) )+
							_FBht      		* (ht )+
							_FBhtR     		* (ht**(-1) )+
							_FBmtadsub3   	* (mt*adult* (sub**3) )+
							_FBmtadtri3R  	* (mt*adult* (tri**(-3)) )+
							_FBmtarmc3R  		* (mt* (armc**(-3)) )+
							_FBmxadarmc3R  	* (mx*adult* (armc**(-3)) )+
							_FBmxarmc2R  		* (mx* (armc**(-2)) )+
							_FBmxcalf3R		* (mx* (calf**(-3)) )+
							_FBsubR       	* (sub**(-1) )+
							_FBtri       		* (tri )+
							_FBtri3R      	* (tri**(-3) )+
							_FBtriR      		* (tri**(-1) )+
							_FBwaistR			* (waist**(-1) )
							
						;
	run;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODB2;
	RUN;	
	
	proc sql;
		create table MOD2 as
		select a.predbf_B, a.ID
		from coefModB as a;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODB;
	RUN;

	PROC SORT DATA=MOD2;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD1 MOD2;
		BY ID;
	RUN;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD1 MOD2;
	RUN;

	*********
	*Model C;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModC(drop=_name_ _label_) prefix=_MC;
	    id parameter;
	    var MModC;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModC(drop=_name_ _label_) prefix=_FC;
	    id parameter;
	    var FModC;
	run;
	*Merge "C" data sets;
	proc sql;
		create table coefModC2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML, t.LEG, t.MENSES,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModC as m, coefFModC as f, &usedata as t;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFFMODC COEFMMODC;
	RUN;

	*Calculate Predicted body fat;
	data coefModC;
		set coefModC2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBF_C=
						_MCintercept +
						_MCadage2Rbmi3 	* (adult* (age**(-2))* (bmi**3) )+
						_MCadage2Rht3R 	* (adult* (age**(-2))* (ht**(-3)) )+
						_MCadage2calf3R	* (adult* (age**2)* (calf**(-3)) )+
						_MCadage3Rarmc3 	* (adult* (age**(-3))* (armc**3) )+
						_MCadage3Rbmi2 	* (adult* (age**(-3))* (bmi**2) )+
						_MCadage3armc3	* (adult* (age**3)* (armc**3) )+
						_MCadage3subR   	* (adult* (age**3)* (sub**(-1)) )+
						_MCadageRwaist3R 	* (adult* (age**(-1))* (waist**(-3)) )+
						_MCadagecalf3R 	* (adult*age* (calf**(-3)) )+
						_MCadageht3 		* (adult*age* (ht**3) )+
						_MCadagethic3     * (adult*age* (thic**3) )+
						_MCadht3 			* (adult* (ht**3) )+
						_MCage2Rcalf3 	* ((age**(-2))* (calf**3) )+
						_MCage2Rthic3		* ((age**(-2))* (thic**3) )+
						_MCage2Rwt3 		* ((age**(-2))* (wt**3) )+
						_MCage3Rarmc3R  	* ((age**(-3))* (armc**(-3)) )+
						_MCage3Rht3R  	* ((age**(-3))* (ht**(-3)) )+
						_MCage3Rsub3 		* ((age**(-3))* (sub**3) )+
						_MCage3Rthic3R 	* ((age**(-3))* (thic**(-3)) )+
						_MCage3Rwt2R   	* ((age**(-3))* (wt**(-2)) )+
						_MCageRsub  		* ((age**(-1))* sub )+
						_MCageRthic3		* ((age**(-1))* (thic**3) )+
						_MCageRwaist2    	* ((age**(-1))* (waist**2) )+
						_MCageRwt3      	* ((age**(-1))* (wt**3) )+
						_MCagesub3  		* (age* (sub**3) )+
						_MCagewaist3R  	* (age* (waist**(-3)) )+
						_MCagewt3R    	* (age* (wt**(-3)) )+
						_MCarmc2    		* (armc**2 )+
						_MCbkadsub3R  	* (bk*adult* (sub**(-3)) )+
						_MCbkadwt3R		* (bk*adult* (wt**(-3)) )+
						_MCbkarmc3   		* (bk* (armc**3) )+
						_MCbksubR  		* (bk* (sub**(-1)) )+
						_MCbkwt3R     	* (bk* (wt**(-3)) )+
						_MCbmi3     		* (bmi**3 )+
						_MCbmi3R   		* (bmi**(-3) )+
						_MCcalf3R    		* (calf**(-3) )+
						_MCht      		* (ht )+
						_MChtR  			* (ht**(-1) )+
						_MCmtadbmi3R		* (mt*adult* (bmi**(-3)) )+
						_MCmtadthic3R 	* (mt*adult* (thic**(-3)) )+
						_MCmtsub2R    	* (mt* (sub**(-2)) )+
						_MCmtthic3   		* (mt* (thic**3) )+
						_MCmxadsub3 		* (mx*adult* (sub**3) )+
						_MCmxadsub3R   	* (mx*adult* (sub**(-3)) )+
						_MCmxadwt3  		* (mx*adult* (wt**3) )+
						_MCmxadwt3R   	* (mx*adult* (wt**(-3)) )+
						_MCmxsub3			* (mx* (sub**3) )+
						_MCmxwt3          * (mx* (wt**3) )+
						_MCsub3      		* (sub**3 )+
						_MCsubR      		* (sub**(-1) )+
						_MCwaist      	* (waist )+
						_MCwtR			* (wt**(-1) )
						
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBF_C=	
							_FCintercept +
							_FCadage2ht3		* (adult* (age**2)* (ht**3) )+
							_FCadage3Rsub2  	* (adult* (age**(-3))* (sub**2) )+
							_FCadage3sub2R  	* (adult* (age**3)* (sub**(-2)) )+
							_FCadage3sub3  	* (adult* (age**3)* (sub**3) )+
							_FCadage3sub3R   	* (adult* (age**3)* (sub**(-3)) )+
							_FCadagethic		* (adult*age*thic )+
							_FCadbmi3R    	* (adult* (bmi**(-3)) )+
							_FCadwt3R   		* (adult* (wt**(-3)) )+
							_FCage2Rbmi3  	* ((age**(-2))* (bmi**3) )+
							_FCage2Rbmi3R  	* ((age**(-2))* (bmi**(-3)) )+
							_FCage3Rarmc3   	* ((age**(-3))* (armc**3) )+
							_FCage3Rbmi3R    	* ((age**(-3))* (bmi**(-3)) )+
							_FCageRsub    	* ((age**(-1))* sub )+
							_FCagethic		* (age*thic )+
							_FCagethic2    	* (age* (thic**2) )+
							_FCarmcR   		* (armc**(-1) )+
							_FCbkadthic3R    	* (bk*adult* (thic**(-3)) )+
							_FCbkbmi3    		* (bk* (bmi**3) )+
							_FCbkcalf3R    	* (bk* (calf**(-3)) )+
							_FCbkht3      	* (bk* (ht**3) )+
							_FCbksubR  		* (bk* (sub**(-1)) )+
							_FCbkthic2R		* (bk* (thic**(-2)) )+
							_FCbkwaist2    	* (bk* (waist**2) )+
							_FCbmiR    		* (bmi**(-1))+
							_FCcalf2R    		* (calf**(-2) )+
							_FCcalf3R      	* (calf**(-3) )+
							_FCht       		* (ht )+
							_FChtR    		* (ht**(-1) )+
							_FCmtadarmc3      * (mt*adult* (armc**3) )+
							_FCmtsub3			* (mt* (sub**3) )+
							_FCmxadarmc3R   	* (mx*adult* (armc**(-3)) )+
							_FCmxcalf2R   	* (mx* (calf**(-2)) )+
							_FCmxcalf3R       * (mx* (calf**(-3)) )+
							_FCmxthic3     	* (mx* (thic**3) )+
							_FCsub       		* (sub )+
							_FCsubR     		* (sub**(-1) )+
							_FCthic     		* (thic )+
							_FCwaistR			* (waist**(-1) )
						
						;
	run;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODC2;
	RUN;
	
	proc sql;
		create table MOD3 as
		select a.predbf_C, a.ID
		from coefModC as a;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODC;
	RUN;

	PROC SORT DATA=MOD3;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD3;
		BY ID;
	RUN;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD3;
	RUN;

	*********
	*Model D;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModD(drop=_name_ _label_) prefix=_MD;
	    id parameter;
	    var MModD;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModD(drop=_name_ _label_) prefix=_FD;
	    id parameter;
	    var FModD;
	run;
	*Merge "D" data sets;
	proc sql;
		create table coefModD2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML, t.LEG, t.MENSES,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModD as m, coefFModD as f, &usedata as t;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFFMODD COEFMMODD;
	RUN;

	*Calculate Predicted body fat;
	data coefModD;
		set coefModD2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")  then

				predBF_D=
						_MDintercept +
						_MDadage3Rwaist3R	* (adult* (age**(-3))* (waist**(-3)) )+
						_MDadage3tri		* (adult* (age**3)* tri )+
						_MDadageRtri3R	* (adult* (age**(-1))* (tri**(-3)) )+ 						
						_MDadageht3     	* (adult*age* (ht**3) )+
						_MDadht3   		* (adult* (ht**3) )+
						_MDadtri3   		* (adult* (tri**3) )+
						_MDadtri3R		* (adult* (tri**(-3)) )+
						_MDage2Rwt3   	* ((age**(-2))* (wt**3) )+
						_MDage3Rtri3     	* ((age**(-3))* (tri**3) )+
						_MDageRtri   		* ((age**(-1))* tri )+
						_MDageRwt2    	* ((age**(-1))* (wt**2) )+
						_MDageRwt3   		* ((age**(-1))* (wt**3) )+
						_MDagecalf3R  	* (age* (calf**(-3)) )+
						_MDagewaist3R  	* (age* (waist**(-3)) )+  
						_MDarmc2			* (armc**2 )+
						_MDarmc3     		* (armc**3 )+
						_MDbkadtri3    	* (bk*adult* (tri**3) )+ 
						_MDbkarmc3      	* (bk* (armc**3) )+
						_MDht    			* (ht )+
						_MDmtadthic3R  	* (mt*adult* (thic**(-3)) )+
						_MDmtadtri  		* (mt*adult* tri )+
						_MDmtarmc3R    	* (mt* (armc**(-3)) )+
						_MDmxadwt3		* (mx*adult* (wt**3) )+
						_MDmxarmc3R 		* (mx* (armc**(-3)) )+
						_MDmxcalf3R 		* (mx* (calf**(-3)) )+
						_MDmxtri3R 		* (mx* (tri**(-3)) )+
						_MDmxwt2R     	* (mx* (wt**(-2)) )+
						_MDmxwt3  		* (mx* (wt**3) )+
						_MDthic3R   		* (thic**(-3) )+
						_MDtri    		* (tri )+
						_MDtriR   		* (tri**(-1) )+
						_MDwaist  		* (waist )+
						_MDwaistR			* (waist**(-1) )
					
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

							_FDintercept +
							_FDBMI    		* (bmi )+
							_FDadage2ht3  	* (adult* (age**2)* (ht**3) )+
							_FDadage3Rbmi3  	* (adult* (age**(-3))* (bmi**3) )+
							_FDadage3Rthic3  	* (adult* (age**(-3))* (thic**3) )+
							_FDadage3Rtri2  	* (adult* (age**(-3))* (tri**2) )+
							_FDadage3Rtri3R	* (adult* (age**(-3))* (tri**(-3)) )+
							_FDadage3tri3  	* (adult* (age**3)* (tri**3) )+	
							_FDadage3tri3R  	* (adult* (age**3)* (tri**(-3)) )+
							_FDadage3waist2R  * (adult* (age**3)* (waist**(-2)) )+
							_FDadagewt3R   	* (adult* age* (wt**(-3)) )+
							_FDadbmi3R   		* (adult* (bmi**(-3)) )+
							_FDadwt3R   		* (adult* (wt**(-3)) )+
							_FDage2Rbmi3		* ((age**(-2))* (bmi**3) )+
							_FDage2Rtri2  	* ((age**(-2))* (tri**2) )+
							_FDage2Rwaist3   	* ((age**(-2))* (waist**3) )+
							_FDage2thic2  	* ((age**2)* (thic**2) )+
							_FDage3Rbmi3R  	* ((age**(-3))* (bmi**(-3)) )+
							_FDage3Rwaist3   	* ((age**(-3))* (waist**3) )+
							_FDagethic2  		* (age* (thic**2) )+
							_FDbkadthic3R		* (bk*adult* (thic**(-3)) )+
							_FDbkadtri3     	* (bk*adult* (tri**3) )+
							_FDbkarmc3    	* (bk* (armc**3) )+
							_FDbkcalf3R   	* (bk* (calf**(-3)) )+
							_FDbkthicR    	* (bk* (thic**(-1)) )+
							_FDbkwaist    	* (bk* waist )+
							_FDbkwaist2     	* (bk* (waist**2) )+
							_FDbmiR    		* (bmi**(-1) )+
							_FDcalf2R			* (calf**(-2) )+
							_FDcalf3R      	* (calf**(-3) )+
							_FDht      		* (ht )+	
							_FDhtR     		* (ht**(-1) )+
							_FDmtadarmc3  	* (mt*adult* (armc**3) )+
							_FDmtadtri3R  	* (mt*adult* (tri**(-3)) )+
							_FDmtarmc3R  		* (mt* (armc**(-3)) )+
							_FDmxadarmc3R  	* (mx*adult* (armc**(-3)) )+
							_FDmxarmc2R		* (mx* (armc**(-2)) )+
							_FDmxarmc3R    	* (mx* (armc**(-3)) )+
							_FDmxcalf3R      	* (mx* (calf**(-3)) )+
							_FDtri       		* (tri )+
							_FDtri3R      	* (tri**(-3) )+
							_FDtriR      		* (tri**(-1) )+
							_FDwaistR			* (waist**(-1) )
							
					;
	run;	

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODD2;
	RUN;
	
	proc sql;
		create table MOD4 as
		select a.predbf_d, a.ID
		from coefModD as a;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODD;
	RUN;

	PROC SORT DATA=MOD4;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD4;
		BY ID;
	RUN;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD4;
	RUN;

	*********
	*Model E;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModE(drop=_name_ _label_) prefix=_ME;
	    id parameter;
	    var MModE;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModE(drop=_name_ _label_) prefix=_FE;
	    id parameter;
	    var FModE;
	run;
	*Merge "E" data sets;
	proc sql;
		create table coefModE2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML, t.LEG, t.MENSES,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModE as m, coefFModE as f, &usedata as t;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODE COEFFMODE;
	RUN;

	*Calculate Predicted body fat;
	data coefModE;
		set coefModE2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBF_E= 
						_MEintercept +
						_MEadage3Rarmc3	* (adult* (age**(-3))* (armc**3) )+
						_MEadage3Rwt3    	* (adult* (age**(-3))* (wt**3) )+
						_MEadage3armc3    * (adult* (age**3)* (armc**3) )+
						_MEadage3calf3R   * (adult* (age**3)* (calf**(-3)) )+
						_MEadage3thic3	* (adult* (age**3)* (thic**3) )+
						_MEadageRwaist3R  * (adult* (age**(-1))* (waist**(-3)) )+ 
						_MEadageht3   	* (adult*age* (ht**3) )+
						_MEadagethic3   	* (adult*age* (thic**3) )+
						_MEadagewt3       * (adult*age* (wt**3) )+
						_MEadht3   		* (adult* (ht**3) )+
						_MEage2Rcalf3   	* ((age**(-2))* (calf**3) )+
						_MEage2Rthic2		* ((age**(-2))* (thic**2) )+
						_MEage2Rthic3    	* ((age**(-2))* (thic**3) )+
						_MEage2Rwt3   	* ((age**(-2))* (wt**3) )+
						_MEage3Rarmc3R    * ((age**(-3))* (armc**(-3)) )+
						_MEage3Rht3R   	* ((age**(-3))* (ht**(-3)) )+
						_MEage3Rwaist3   	* ((age**(-3))* (waist**3) )+
						_MEageRthic3    	* ((age**(-1))* (thic**3) )+
						_MEageRwaist2		* ((age**(-1))* (waist**2) )+
						_MEagewaist3R  	* (age* (waist**(-3)) )+
						_MEagewt3R     	* (age* (wt**(-3)) )+
						_MEarmc3     		* (armc**3 )+
						_MEbkadarmc3  	* (bk*adult* (armc**3) )+
						_MEbkadwt3R    	* (bk*adult* (wt**(-3)) )+
						_MEbkarmc3  		* (bk* (armc**3) )+
						_MEbkarmc3R    	* (bk* (armc**(-3)) )+
						_MEbkht3			* (bk* (ht**3) )+
						_MEbkwt3R     	* (bk* (wt**(-3)) )+
						_MEbmi3      		* (bmi**3 )+
						_MEcalf3R     	* (calf**(-3) )+
						_MEht      		* (ht )+
						_MEhtR   			* (ht**(-1) )+
						_MEmtadbmi3R  	* (mt*adult* (bmi**(-3)) )+
						_MEmtadthic3R     * (mt*adult* (thic**(-3)) )+
						_MEmtthic3		* (mt* (thic**3) )+
						_MEmxadwt3     	* (mx*adult* (wt**3) )+
						_MEmxadwt3R    	* (mx*adult* (wt**(-3)) )+
						_MEmxwaist3R    	* (mx* (waist**(-3)) )+
						_MEmxwt3R     	* (mx* (wt**(-3)) )+
						_MEwaist     		* (waist)+
						_MEwaistR			* (waist**(-1))
						
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBF_E=	
							_FEintercept +
							_FEadage2ht3    	* (adult* (age**2)* (ht**3) )+
							_FEadage2waist2R  * (adult* (age**2)* (waist**(-2)) )+
							_FEadage3Rthic3   * (adult* (age**(-3))* (thic**3) )+ 
							_FEadage3bmi3    	* (adult* (age**3)* (bmi**3) )+
							_FEadage3waist3	* (adult* (age**3)* (waist**3) )+
							_FEadage3waist3R  * (adult* (age**3)* (waist**(-3)) )+  
							_FEadagebmi3   	* (adult*age* (bmi**3) )+
							_FEadageht3   	* (adult*age* (ht**3) )+
							_FEadbmi3R     	* (adult* (bmi**(-3)) )+
							_FEadwt3R    		* (adult* (wt**(-3)) )+
							_FEage2Rbmi3   	* ((age**(-2))* (bmi**3) )+
							_FEage2Rwaist3	* ((age**(-2))* (waist**3) )+
							_FEage3Rarmc3   	* ((age**(-3))* (armc**3) )+
							_FEage3Rbmi3R    	* ((age**(-3))* (bmi**(-3)) )+
							_FEagethic2    	* (age* (thic**2) )+
							_FEarmcR    		* (armc**(-1) )+
							_FEbkadthic3R     * (bk*adult* (thic**(-3)) )+
							_FEbkbmi3     	* (bk* (bmi**3) )+
							_FEbkcalf3R		* (bk* (calf**(-3)) )+
							_FEbkthic2R    	* (bk* (thic**(-2)) )+
							_FEbmiR   		* (bmi**(-1) )+
							_FEcalf2R     	* (calf**(-2) )+
							_FEht      		* (ht )+
							_FEhtR    		* (ht**(-1) )+
							_FEmtadarmc3R   	* (mt*adult* (armc**(-3)) )+
							_FEmtadbmi3   	* (mt*adult* (bmi**3) )+
							_FEmtwaist3R		* (mt* (waist**(-3)) )+
							_FEmxadbmi3R    	* (mx*adult* (bmi**(-3)) )+
							_FEmxarmc2R    	* (mx* (armc**(-2)) )+
							_FEmxbmi3R      	* (mx* (bmi**(-3)) )+
							_FEthic     		* (thic )+
							_FEwaist2R     	* (waist**(-2) )+
							_FEwaistR			* (waist**(-1) )
							;
	run;	

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODE2;
	RUN;
	
	proc sql;
		create table MOD5 as
		select a.predbf_E, a.ID
		from coefModE as a;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODE;
	RUN;

	PROC SORT DATA=MOD5;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD5;
		BY ID;
	RUN;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD5;
	RUN;

	*********
	*Model F;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModF(drop=_name_ _label_) prefix=_MF;
	    id parameter;
	    var MModF;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModF(drop=_name_ _label_) prefix=_FF;
	    id parameter;
	    var FModF;
	run;
	*Merge "F" data sets;
	proc sql;
		create table coefModF2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML, t.LEG, t.MENSES,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModF as m, coefFModF as f, &usedata as t;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFFMODF COEFMMODF;
	RUN;

	*Calculate Predicted body fat;
	data coefModF;
		set coefModF2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBF_F= 
						_MFintercept +
						_MFadage2Rwaist3R	* (adult* (age**(-2))* (waist**(-3)) )+
						_MFadage3tri 		* (adult* (age**3)* tri )+
						_MFadage3waist2  	* (adult* (age**3)* (waist**2) )+
						_MFadageRtri3R   	* (adult* (age**(-1))* (tri**(-3)) )+
						_MFadageRwaist3R  * (adult* (age**(-1))* (waist**(-3)) )+
						_MFadagecalf3R 	* (adult* age* (calf**(-3)) )+
						_MFadageht3		* (adult* age* (ht**3)  )+
						_MFadtri3  		* (adult* (tri**3) )+
						_MFadtri3R 		* (adult* (tri**(-3)) )+
						_MFage3Rcalf3 	* ((age**(-3))* (calf**3) )+
						_MFage3Rtri3   	* ((age**(-3))* (tri**3) )+
						_MFageRsub    	* ((age**(-1))* sub )+
						_MFageRtri     	* ((age**(-1))* tri )+
						_MFageRwaist3  	* ((age**(-1))* (waist**3) )+
						_MFageRwt2  		* ((age**(-1))* (wt**2) )+
						_MFagecalf3R		* (age* (calf**(-3)) )+
						_MFagesub3 		* (age* (sub**3) )+
						_MFagewaist3R 	* (age* (waist**(-3)) )+
						_MFagewt3R   		* (age* (wt**(-3)) )+
						_MFbkadtri3   	* (bk*adult* (tri**3) )+
						_MFbkbmi2   		* (bk* (bmi**2) )+
						_MFbkwt   		* (bk* wt )+
						_MFbmi3R   		* (bmi**(-3) )+
						_MFcalf2R    		* (calf**(-2) )+
						_MFht				* (ht )+
						_MFhtR    		* (ht**(-1) )+
						_MFmtadbmi3R  	* (mt*adult* (bmi**(-3)) )+
						_MFmtadtri  		* (mt*adult* tri )+
						_MFmxtri3R  		* (mx* (tri**(-3)) )+
						_MFmxwt2R      	* (mx* (wt**(-2)) )+
						_MFmxwt3    		* (mx* (wt**3) )+
						_MFsubR     		* (sub**(-1) )+
						_MFtriR    		* (tri**(-1) )+
						_MFwaist			* (waist )
					
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")  then 

				predBF_F=	
							_FFintercept +
							_FFBMI    		* (bmi )+
							_FFadage2ht3     	* (adult* (age**2)* (ht**3) )+
							_FFadage2wt   	* (adult* (age**2)* wt )+
							_FFadage3Rsub3   	* (adult* (age**(-3))* (sub**3) )+
							_FFadage3Rtri3R   * (adult* (age**(-3))* (tri**(-3)) )+
							_FFadage3sub3		* (adult* (age**3)* (sub**3) )+
							_FFadage3sub3R 	* (adult* (age**3)* (sub**(-3)) )+
							_FFadage3subR   	* (adult* (age**3)* (sub**(-1)) )+
							_FFadageRsubR   	* (adult* (age**(-1))* (sub**(-1)) )+
							_FFadagewt   		* (adult* age* wt )+
							_FFadbmi3R 		* (adult* (bmi**(-3)) )+
							_FFage2Rsub2 		* ((age**(-2))* (sub**2) )+
							_FFage2Rtri2 		* ((age**(-2))* (tri**2) )+
							_FFage3Rbmi3R		* ((age**(-3))* (bmi**(-3)) )+
							_FFage3Rtri2  	* ((age**(-3))* (tri**2) )+
							_FFageRsub2  		* ((age**(-1))* (sub**2) )+
							_FFbkcalfR      	* (bk* (calf**(-1)) )+
							_FFbkht2  		* (bk* (ht**2) )+
							_FFbksubR  		* (bk* (sub**(-1)) )+
							_FFbktriR    		* (bk* (tri**(-1)) )+
							_FFbmiR    		* (bmi**(-1) )+
							_FFcalf3R     	* (calf**(-3) )+
							_FFht2R			* (ht**(-2) )+
							_FFhtR     		* (ht**(-1) )+
							_FFmxcalf3R      	* (mx* (calf**(-3)) )+
							_FFsubR       	* (sub**(-1) )+
							_FFtri        	* (tri )+
							_FFtriR      		* (tri**(-1) )+
							_FFwaistR			* (waist**(-1) )
							
					;
	run;	

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODF2;
	RUN;
	
	proc sql;
		create table MOD6 as
		select a.predbf_F, a.ID
		from coefModF as a;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODF;
	RUN;

	PROC SORT DATA=MOD6;
		BY ID;
	RUN;


	DATA MOD;
		MERGE MOD MOD6;
		BY ID;
	RUN;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD6;
	RUN;

	*********
	*Model G;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModG(drop=_name_ _label_) prefix=_MG;
	    id parameter;
	    var MModG;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModG(drop=_name_ _label_) prefix=_FG;
	    id parameter;
	    var FModG;
	run;
	*Merge "G" data sets;
	proc sql;
		create table coefModG2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML, t.LEG, t.MENSES,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModG as m, coefFModG as f, &usedata as t;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODG COEFFMODG;
	RUN;

	*Calculate Predicted body fat;
	data coefModG;
		set coefModG2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBF_G= 
						_MGintercept +
						_MGadage2Rwaist3R	* (adult* (age**(-2))* (waist**(-3)) )+
						_MGadage3Rwaist3R * (adult* (age**(-3))* (waist**(-3)) )+
						_MGadage3tri  	* (adult* (age**3)* tri )+
						_MGadage3waist   	* (adult* (age**3)* waist )+
						_MGadageRtri3R  	* (adult* (age**(-1))* (tri**(-3)) )+
						_MGadageht3		* (adult* age* (ht**3) )+
						_MGadtri3R 		* (adult* (tri**(-3)) )+
						_MGage2Rsub 		* ((age**(-2))* sub )+
						_MGage3Rtri3   	* ((age**(-3))* (tri**3) )+
						_MGageRsub    	* ((age**(-1))* sub)+
						_MGageRtri   		* ((age**(-1))* tri )+
						_MGageRwt2  		* ((age**(-1))* (wt**2) )+
						_MGagearmc3R    	* (age* (armc**(-3)) )+
						_MGagesub3 		* (age* (sub**3) )+
						_MGagewt3R		* (age* (wt**(-3)) )+
						_MGarmc   		* (armc )+
						_MGarmc3R   		* (armc**(-3) )+
						_MGbkadtri3    	* (bk*adult* (tri**3) )+
						_MGbkarmc3   		* (bk* (armc**3) )+
						_MGbkwaist2R  	* (bk* (waist**(-2)) )+
						_MGbkwaist3R     	* (bk* (waist**(-3)) )+
						_MGht    			* (ht )+
						_MGmtadbmi3R		* (mt*adult* (bmi**(-3)) )+
  						_MGmtadtri   		* (mt*adult* tri )+
						_MGmxtri3R   		* (mx* (tri**(-3)) )+
						_MGmxwt2R       	* (mx* (wt**(-2)) )+
						_MGmxwt3     		* (mx* (wt**3) )+
						_MGsubR       	* (sub**(-1) )+
						_MGtri       		* (tri )+
						_MGtriR     		* (tri**(-1) )+
						_MGwaist			* (waist )
						
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBF_G=	
							_FGintercept +
							_FGBMI			* (bmi )+
							_FGadage2ht3    	* (adult* (age**2)* (ht**3) )+
							_FGadage2wt   	* (adult* (age**2)* (wt) )+
							_FGadage3Rsub2   	* (adult* (age**(-3))* (sub**2) )+
							_FGadage3Rtri3R   * (adult* (age**(-3))* (tri**(-3)) )+
							_FGadage3sub3     * (adult* (age**3)* (sub**3) )+                                          
							_FGadage3sub3R   	* (adult* (age**3)* (sub**(-3)) )+
							_FGadage3subR   	* (adult* (age**3)* (sub**(-1)) )+
							_FGadage3tri3    	* (adult* (age**3)* (tri**3) )+
							_FGadageRsubR     * (adult* (age**(-1))* (sub**(-1)) )+ 
							_FGadagewt     	* (adult* age* wt )+
							_FGadbmi3R   		* (adult* (bmi**(-3)) )+
							_FGage2Rtri2		* ((age**(-2))* (tri**2) )+
							_FGage3Rbmi3R    	* ((age**(-3))* (bmi**(-3)) )+
							_FGageRsub2     	* ((age**(-1))* (sub**2) )+
							_FGagewt   		* (age*wt )+
							_FGbkbmiR    		* (bk* (bmi**(-1)) )+
							_FGbkht    		* (bk* ht )+
							_FGbksubR   		* (bk* (sub**(-1)) )+
							_FGbktriR    		* (bk* (tri**(-1)) )+
							_FGbmiR      		* (bmi**(-1) )+
							_FGht2R			* (ht**(-2) )+
							_FGhtR      		* (ht**(-1) )+
							_FGmxarmc2R      	* (mx* (armc**(-2)) )+
							_FGraceBlack      * (bk )+ 
							_FGsubR       	* (sub**(-1) )+
							_FGtri       		* (tri )+
							_FGtriR      		* (tri**(-1) )+
							_FGwaistR			* (waist**(-1) )
							
						;
	run;	

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODG2;
	RUN;
	
	proc sql;
		create table MOD7 as
		select a.predbf_G, a.ID
		from coefModG as a;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODG;
	RUN;

	PROC SORT DATA=MOD7;
		BY ID;
	RUN;


	DATA MOD;
		MERGE MOD MOD7;
		BY ID;
	RUN;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD7;
	RUN;

	*********
	*Model H;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModH(drop=_name_ _label_) prefix=_MH;
	    id parameter;
	    var MModH;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModH(drop=_name_ _label_) prefix=_FH;
	    id parameter;
	    var FModH;
	run;
	*Merge "H" data sets;
	proc sql;
		create table coefModH2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML, t.LEG, t.MENSES,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModH as m, coefFModH as f, &usedata as t;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODH COEFFMODH;
	RUN;

	*Calculate Predicted body fat;
	data coefModH;
		set coefModH2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")  then

				predBF_H= 
						_MHintercept +
						_MHBMI			* (bmi )+
						_MHadage2bmi  	* (adult* (age**2)* bmi )+
						_MHadage3RsubR  	* (adult* (age**(-3))* (sub**(-1)) )+
						_MHadage3Rwt2R  	* (adult* (age**(-3))* (wt**(-2)) )+
						_MHadage3RwtR  	* (adult* (age**(-3))* (wt**(-1)) )+
						_MHadage3ht3R   	* (adult* (age**3)* (ht**(-3)) )+
						_MHadageRtri3R	* (adult* (age**(-1))* (tri**(-3)) )+
						_MHadagebmi  		* (adult* age* bmi )+
						_MHadagewt  		* (adult* age* wt )+
						_MHadagewt2   	* (adult* age* (wt**2) )+
						_MHadtri3  		* (adult* (tri**3))+
						_MHadtri3R 		* (adult* (tri**(-3)) )+
						_MHage2Rbmi3   	* ((age**(-2))* (bmi**3) )+
						_MHageRsub    	* ((age**(-1))* sub )+
						_MHageRtri  		* ((age**(-1))* tri )+
						_MHagearmc3R		* (age* (armc**(-3)) )+
						_MHagesub3     	* (age* (sub**3) )+
						_MHarmc3     		* (armc**3 )+
						_MHarmc3R   		* (armc**(-3) )+
						_MHbkarmc     	* (bk* armc )+
						_MHbkarmc2     	* (bk* (armc**2) )+
						_MHbkht3R     	* (bk* (ht**(-3)) )+
						_MHbksubR     	* (bk* (sub**(-1)) )+
						_MHbmi2			* (bmi**2 )+
						_MHht     		* (ht )+
						_MHhtR   			* (ht**(-1) )+
						_MHmttri2R 		* (mt* (tri**(-2)) )+
						_MHmxarmc3R 		* (mx* (armc**(-3)) )+
						_MHmxtri2R 		* (mx* (tri**(-2)) )+
						_MHmxtri3R  		* (mx* (tri**(-3)) )+   
						_MHmxwt3   		* (mx* (wt**3) )+
						_MHsubR    		* (sub**(-1) )+
						_MHtri    		* (tri )+
						_MHtriR			* (tri**(-1) )
						
						;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBF_H=
							_FHintercept +
							_FHBMI			* (bmi )+
							_FHadage2ht2    	* (adult* (age**2)* (ht**2) )+
							_FHadage2ht3    	* (adult* (age**2)* (ht**3) )+
							_FHadage2wt   	* (adult* (age**2)* wt )+
							_FHadage3Rsub3   	* (adult* (age**(-3))* (sub**3) )+
							_FHadage3Rtri3R	* (adult* (age**(-3))* (tri**(-3)) )+
							_FHadage3sub3   	* (adult* (age**3)* (sub**3) )+
							_FHadage3sub3R   	* (adult* (age**3)* (sub**(-3)) )+
							_FHadage3subR   	* (adult* (age**3)* (sub**(-1)) )+
							_FHadage3tri3    	* (adult* (age**3)* (tri**3) )+
							_FHadageRsubR     * (adult* (age**(-1))* (sub**(-1)) )+
							_FHadagewt     	* (adult*age* wt )+
							_FHadbmi3R		* (adult* (bmi**(-3)) )+
							_FHage2Rtri2 		* ((age**(-2))* (tri**2) )+
							_FHage3Rbmi3R   	* ((age**(-3))* (bmi**(-3)) )+
							_FHageRsub2  		* ((age**(-1))* (sub**2) )+
							_FHbkbmiR  		* (bk* (bmi**(-1)) )+
							_FHbkhtR   		* (bk* (ht**(-1)) )+
							_FHbksubR  		* (bk* (sub**(-1)) )+
							_FHbktriR   		* (bk* (tri**(-1)) )+
							_FHbmiR     		* (bmi**(-1) )+
							_FHht2R			* (ht**(-2) )+
							_FHhtR     		* (ht**(-1) )+
							_FHmxadarmc3R    	* (mx*adult* (armc**(-3)) )+
							_FHmxarmc2R     	* (mx* (armc**(-2)) )+
							_FHraceBlack     	* (bk )+  
							_FHsubR       	* (sub**(-1) )+
							_FHtri       		* (tri )+
							_FHtriR			* (tri**(-1) )
							
					;
	run;		

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODH2;
	RUN;
	
	proc sql;
		create table MOD8 as
		select a.predbf_H, a.ID
		from coefModH as a;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODH;
	RUN;

	PROC SORT DATA=MOD8;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD8;
		BY ID;
	RUN;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD8;
	RUN;

	*********
	*Model I;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModI(drop=_name_ _label_) prefix=_MI;
	    id parameter;
	    var MModI;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModI(drop=_name_ _label_) prefix=_FI;
	    id parameter;
	    var FModI;
	run;
	*Merge "I" data sets;
	proc sql;
		create table coefModI2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML, t.LEG, t.MENSES,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModI as m, coefFModI as f, &usedata as t;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODI COEFFMODI;
	RUN;

	*Calculate Predicted body fat;
	data coefModI;
		set coefModI2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBF_I= 
						_MIintercept +
						_MIadage2Rwaist3R	* (adult* (age**(-2))* (waist**(-3)) )+
						_MIadage3tri   	* (adult* (age**3)* tri )+
						_MIadage3waist    * (adult* (age**3)* waist )+
						_MIadageRtri3R    * (adult* (age**(-1))* (tri**(-3)) )+
						_MIadageRwaist3R  * (adult* (age**(-1))* (waist**(-3)) )+
						_MIadageht3		* (adult* age* (ht**3) )+
						_MIadtri3R  		* (adult* (tri**(-3)) )+
						_MIage2Rwaist3  	* ((age**(-2))* (waist**3) )+
						_MIage3Rtri3    	* ((age**(-3))* (tri**3) )+
						_MIageRtri      	* ((age**(-1))* tri )+
						_MIageRwaist3   	* ((age**(-1))* (waist**(3)) )+
						_MIageRwt2   		* ((age**(-1))* (wt**(2)) )+
						_MIagewaist3R  	* (age* (waist**(-3)) )+
						_MIagewt2R		* (age* (wt**(-2)) )+
						_MIagewt3R    	* (age* (wt**(-3)) )+
						_MIbkadbmi2      	* (bk*adult* (bmi**2) )+
						_MIbkbmi2      	* (bk* (bmi**2) )+
						_MIbkwt       	* (bk* wt )+
						_MIbkwt2      	* (bk* (wt**2) )+
						_MIbmi3R      	* (bmi**(-3) )+
						_MIht       		* (ht )+
						_MIhtR			* (ht**(-1) )+
						_MImtadbmi3R   	* (mt*adult* (bmi**(-3)) )+
						_MImtadtri   		* (mt*adult* tri)+
						_MImxtri3R    	* (mx* (tri**(-3)) )+
						_MImxwt2R       	* (mx* (wt**(-2)) )+
						_MImxwt3    		* (mx* (wt**3) )+
						_MImxwtR     		* (mx* (wt**(-1)) )+
						_MItriR     		* (tri**(-1) )+
						_MIwaist			* (waist )
						
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBF_I=	
							_FIintercept +
							_FIBMI			* (bmi )+
							_FIadage2ht3   	* (adult* (age**2)* (ht**3) )+
							_FIadage3Rtri3R   * (adult* (age**(-3))* (tri**(-3)) )+
							_FIadage3tri3   	* (adult* (age**3)* (tri**3) )+
							_FIadage3tri3R   	* (adult* (age**3)* (tri**(-3)) )+
							_FIadage3triR		* (adult* (age**3)* (tri**(-1)) )+
							_FIadageRbmi3R    * (adult* (age**(-1))* (bmi**(-3)) )+
							_FIadagewt    	* (adult*age*wt )+
							_FIadbmi3R  		* (adult* (bmi**(-3)) )+
							_FIage2Rtri2  	* ((age**(-2))* (tri**2) )+
							_FIage3Rbmi3R  	* ((age**(-3))* (bmi**(-3)) )+
							_FIbkbmiR   		* (bk* (bmi**(-1)) )+
							_FIbktriR    		* (bk* (tri**(-1)) )+
							_FIbmiR			* (bmi**(-1) )+
							_FIht2R        	* (ht**(-2) )+
							_FIhtR      		* (ht**(-1) )+
							_FImxwtR      	* (mx* (wt**(-1)) )+
							_FIraceBlack      * (bk )+
							_FItri       		* (tri )+
							_FItriR      		* (tri**(-1) )+
							_FIwaistR			* (waist**(-1) )
							
						;
	run;	


	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODI2;
	RUN;	

	proc sql;
		create table MOD9 as
		select a.predbf_I, a.ID
		from coefModI as a;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODI;
	RUN;

	PROC SORT DATA=MOD9;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD9;
		BY ID;
	RUN;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD9;
	RUN;


	*********
	*Model J;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModJ(drop=_name_ _label_) prefix=_MJ;
	    id parameter;
	    var MModJ;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModJ(drop=_name_ _label_) prefix=_FJ;
	    id parameter;
	    var FModJ;
	run;
	*Merge "J" data sets;
	proc sql;
		create table coefModJ2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML, t.LEG, t.MENSES,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModJ as m, coefFModJ as f, &usedata as t;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODJ COEFFMODJ;
	RUN;


	*Calculate Predicted body fat;
	data coefModJ;
		set coefModJ2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBF_J=
						_MJintercept +
						_MJadage3Rarmc3	* (adult* (age**(-3))* (armc**3) )+
						_MJadage3armc2 	* (adult* (age**3)* (armc**2) )+
						_MJadage3armc3 	* (adult* (age**3)* (armc**3))+
						_MJadage3waist2R 	* (adult* (age**3)* (waist**(-2)) )+
						_MJadage3wt2R   	* (adult* (age**3)* (wt**(-2)) )+
						_MJadageRwaist3R	* (adult* (age**(-1))* (waist**(-3)) )+
						_MJadageht3      	* (adult* age* (ht**3) )+
						_MJadht3  		* (adult* (ht**3) )+
						_MJage2Rarmc2   	* ((age**(-2))* (armc**2) )+
						_MJage2Rwt3   	* ((age**(-2))* (wt**3) )+
						_MJage3Rarmc3R   	* ((age**(-3))* (armc**(-3)) )+
						_MJage3Rht3R  	* ((age**(-3))* (ht**(-3)) )+
						_MJage3Rwaist3	* ((age**(-3))* (waist**3) )+
						_MJage3Rwt2R   	* ((age**(-3))* (wt**(-2)) )+
						_MJageRwaist2  	* ((age**(-1))* (waist**2) )+
						_MJagewaist3R  	* (age* (waist**(-3)) )+
						_MJagewt3R     	* (age* (wt**(-3)) )+
						_MJarmc3    		* (armc**3 )+
						_MJbkadarmc3    	* (bk*adult* (armc**3) )+
						_MJbkarmc3    	* (bk* (armc**3) )+
						_MJbkwt3R			* (bk* (wt**(-3)) )+
						_MJht      		* (ht )+
						_MJmtadbmi3R  	* (mt*adult* (bmi**(-3)) )+    
						_MJmxadwt3    	* (mx*adult* (wt**3) )+ 
						_MJmxadwt3R    	* (mx*adult* (wt**(-3)) )+ 
						_MJmxwt3R     	* (mx* (wt**(-3)) )+
						_MJwaist     		* (waist )+
						_MJwaistR			* (waist**(-1) )
					
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBF_J=	
							_FJintercept +
							_FJBMI   			* (bmi )+
							_FJadage2ht3  	* (adult* (age**2)* (ht**3) )+
							_FJadage2waist2R  * (adult* (age**2)* (waist**(-2)) )+
							_FJadage3Rbmi3  	* (adult* (age**(-3))* (bmi**3) )+
							_FJadage3waist3  	* (adult* (age**3)* (waist**3) )+
							_FJadageht3		* (adult* age* (ht**3) )+
							_FJadbmi3R   		* (adult* (bmi**(-3)) )+
							_FJage2Rbmi3R   	* ((age**(-2))* (bmi**(-3)) )+
							_FJage3Rarmc3    	* ((age**(-3))* (armc**3) )+
							_FJage3Rbmi3R   	* ((age**(-3))* (bmi**(-3)) )+
							_FJage3Rwaist3    * ((age**(-3))* (waist**3) )+
							_FJageRwt3R     	* ((age**(-1))* (wt**(-3)) )+
							_FJarmcR			* (armc**(-1) )+
							_FJbkadwt3R   	* (bk*adult* (wt**(-3)) )+
							_FJbkarmc2R   	* (bk* (armc**(-2)) )+
							_FJbkarmcR     	* (bk* (armc**(-1)) )+
							_FJbmiR       	* (bmi**(-1) )+
							_FJht        		* (ht )+
							_FJhtR    		* (ht**(-1) )+
							_FJmtadbmi3R   	* (mt*adult* (bmi**(-3)) )+
							_FJmtbmi3R		* (mt* (bmi**(-3)) )+
							_FJmxadbmi3R    	* (mx*adult* (bmi**(-3)) )+
							_FJmxarmc2R    	* (mx* (armc**(-2)) )+
							_FJmxbmi2R    	* (mx* (bmi**(-2)) )+
							_FJmxbmi3R     	* (mx* (bmi**(-3)) )+
							_FJwaist2R    	* (waist**(-2) )+
							_FJwaistR      	* (waist**(-1) )+
							_FJwt3R			* (wt**(-3) )
						
						;
	run;	

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODJ2;
	RUN;
	
	proc sql;
		create table MOD10 as
		select a.predbf_J, a.ID
		from coefModJ as a;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODJ;
	RUN;

	PROC SORT DATA=MOD10;
		BY ID;
	RUN;


	DATA MOD;
		MERGE MOD MOD10;
		BY ID;
	RUN;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD10;
	RUN;

	*********
	*Model K;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModK(drop=_name_ _label_) prefix=_MK;
	    id parameter;
	    var MModK;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModK(drop=_name_ _label_) prefix=_FK;
	    id parameter;
	    var FModK;
	run;
	*Merge "K" data sets;
	proc sql;
		create table coefModK2 as
		select m.*, f.*,
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML, t.LEG, t.MENSES,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModK as m, coefFModK as f, &usedata as t;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODK COEFFMODK;
	RUN;

	*Calculate Predicted body fat;
	data coefModK;
		set coefModK2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBF_K=
						_MKintercept +
						_MKBMI  			* (bmi )+
						_MKadage2Rarmc2 	* (adult* (age**(-2))* (armc**2) )+
						_MKadage2RwtR 	* (adult* (age**(-2))* (wt**(-1)) )+
						_MKadage3Rht3 	* (adult* (age**(-3))* (ht**3) )+
						_MKadage3armc3 	* (adult* (age**3)* (armc**3) )+
						_MKadage3ht3R  	* (adult* (age**3)* (ht**(-3)) )+
						_MKadage3wt3		* (adult* (age**3)* (wt**3) )+
						_MKadageRarmc3   	* (adult* (age**(-1))* (armc**3) )+
						_MKadageRarmc3R   * (adult* (age**(-1))* (armc**(-3)) )+
						_MKadageRwt2R   	* (adult* (age**(-1))* (wt**(-2)) )+
						_MKadageht3 		* (adult* age* (ht**3) )+
						_MKadarmc3R     	* (adult* (armc**(-3)) )+
						_MKadht3   		* (adult* (ht**3) )+
						_MKadwt     		* (adult* wt )+
						_MKadwt2   		* (adult* (wt**2) )+
						_MKage2Rarmc2		* ((age**(-2))* (armc**2) )+
						_MKage3Rarmc2R  	* ((age**(-3))* (armc**(-2)) )+
						_MKage3Rarmc3R   	* ((age**(-3))* (armc**(-3)) )+
						_MKage3Rht3R  	* ((age**(-3))* (ht**(-3)) )+
						_MKage3armc3R    	* ((age**3)* (armc**(-3)) )+
						_MKageRbmi     	* ((age**(-1))* bmi )+
						_MKageRbmi2     	* ((age**(-1))* (bmi**2) )+
						_MKageRbmi3R     	* ((age**(-1))* (bmi**(-3)) )+
						_MKarmc2			* (armc**2 )+
						_MKarmc3    		* (armc**3 )+
						_MKarmc3R  		* (armc**(-3) )+
						_MKbkadarmc3R  	* (bk*adult* (armc**(-3)) )+
						_MKbkadbmi3   	* (bk*adult* (bmi**3) )+
						_MKbkarmc2  		* (bk* (armc**2) )+
						_MKbkbmiR      	* (bk* (bmi**(-1)) )+
						_MKbkht3  		* (bk* (ht**3) )+
						_MKbkwtR    		* (bk* (wt**(-1)) )+
						_MKbmiR			* (bmi**(-1) )+
						_MKhtR   			* (ht**(-1) )+
						_MKmtadarmc3R 	* (mt*adult* (armc**(-3)) )+ 
						_MKmtadbmi3R   	* (mt*adult* (bmi**(-3)) )+ 
						_MKmtadwt3    	* (mt*adult* (wt**3) )+
						_MKmtarmc3    	* (mt* (armc**3) )+
						_MKmtwt3R    		* (mt* (wt**(-3)) )+
						_MKmxadwt3  		* (mx*adult* (wt**3) )+
						_MKmxadwt3R		* (mx*adult* (wt**(-3)) )+
						_MKmxbmi3    		* (mx* bmi**3 )+
                        _MKmxbmi3R   		* (mx* (bmi**(-3)) )+
						_MKmxht3     		* (mx* (ht**3) )+
						_MKmxwt2R        	* (mx* (wt**(-2)) )+
						_MKmxwt3     		* (mx* (wt**3) )+
						_MKmxwt3R        	* (mx* (wt**(-3)) )+
						_MKwt2			* (wt**2 )
					
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")then 

				predBF_K=	
							_FKintercept +
                    		_FKBMI    		* (bmi )+
                    		_FKadage2ht3  	* (adult* (age**2)* (ht**3) )+
                    		_FKadage3Rbmi3    * (adult* (age**(-3))* (bmi**3) )+
                    		_FKadageRarmc3R   * (adult* (age**(-1))* (armc**(-3)) )+
                    		_FKadageht3  		* (adult* age* (ht**3) )+
                    		_FKadbmi3R  		* (adult* (bmi**(-3)) )+
                    		_FKage2Rbmi3		* ((age**(-2))* (bmi**3) )+
                    		_FKage2Rbmi3R  	* ((age**(-2))* (bmi**(-3)) )+
                    		_FKage3Rarmc3   	* ((age**(-3))* (armc**3) )+
                    		_FKage3Rbmi3R   	* ((age**(-3))* (bmi**(-3)) )+
                    		_FKarmcR   		* (armc**(-1) )+
                    		_FKbkarmc2R  		* (bk* (armc**(-2)) )+
                    		_FKbkarmcR    	* (bk* (armc**(-1)) )+
                    		_FKbmiR     		* (bmi**(-1) )+
                    		_FKhtR			* (ht**(-1) )+
                    		_FKmtadarmc3R    	* (mt*adult* (armc**(-3)) )+
                    		_FKmtadbmi3R    	* (mt*adult* (bmi**(-3)) )+
                    		_FKmxadbmi3R    	* (mx*adult* (bmi**(-3)) )+
                    		_FKmxarmc2R    	* (mx* (armc**(-2)) )+
                    		_FKmxbmi2R    	* (mx* (bmi**(-2)) )+
                    		_FKmxbmi3R		* (mx* (bmi**(-3)) )
						;
	run;	

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODK2;
	RUN;
	
	proc sql;
		create table MOD11 as
		select a.predbf_K, a.ID
		from coefModK as a;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODK;
	RUN;

	PROC SORT DATA=MOD11;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD11;
		BY ID;
	RUN;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD11;
	RUN;

	*********
	*Model L;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModL(drop=_name_ _label_) prefix=_ML;
	    id parameter;
	    var MModL;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModL(drop=_name_ _label_) prefix=_FL;
	    id parameter;
	    var FModL;
	run;
	*Merge "L" data sets;
	proc sql;
		create table coefModL2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML, t.LEG, t.MENSES,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModL as m, coefFModL as f, &usedata as t;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODL COEFFMODL;
	RUN;

	*Calculate Predicted body fat;
	data coefModL;
		set coefModL2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")then

				predBF_L= 
						_MLintercept +
						_MLadage3Rbmi3	* (adult* (age**(-3))* (bmi**3) )+
						_MLadage3bmi2   	* (adult* (age**3)* (bmi**2) )+
						_MLadage3ht3R     * (adult* (age**3)* (ht**(-3)) )+
						_MLadageRwaist3R  * (adult* (age**(-1))* (waist**(-3)) )+
						_MLadageht3   	* (adult* age* (ht**3) )+
						_MLadbmi3R		* (adult* (bmi**(-3)) )+
						_MLadht3  		* (adult* (ht**3) )+
						_MLage3Rht3R 		* ((age**(-3))* (ht**(-3)) )+
						_MLage3Rwaist3 	* ((age**(-3))* (waist**3) )+
						_MLage3Rwt2R  	* ((age**(-3))* (wt**(-2)) )+
						_MLageRwaist  	* ((age**(-1))* waist )+
						_MLageRwaist2    	* ((age**(-1))* (waist**2) )+
						_MLageRwt3  		* ((age**(-1))* (wt**3) )+
						_MLagewaist3R		* (age* (waist**(-3)) )+
						_MLagewt3R      	* (age* (wt**(-3)) )+
						_MLbkadwt3   		* (bk*adult* (wt**3) )+
						_MLbkwaist3R     	* (bk* (waist**(-3)) )+   
						_MLbkwt2        	* (bk* (wt**2) )+
						_MLbkwt3    		* (bk* (wt**3) )+
						_MLbkwt3R      	* (bk* (wt**(-3)) )+ 
						_MLbmi3			* (bmi**3 )+
						_MLht      		* (ht )+
						_MLmtadbmi3R    	* (mt*adult* (bmi**(-3)) )+  
						_MLmxadwt3    	* (mx*adult* (wt**3) )+
						_MLmxadwt3R   	* (mx*adult* (wt**(-3)) )+ 
						_MLmxwt3R     	* (mx* (wt**(-3)) )+
						_MLwaist     		* (waist )+
						_MLwaistR			* (waist**(-1) )
						
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBF_L=	_FLintercept +
							_FLBMI    		* (bmi )+
							_FLadage2ht3      * (adult* (age**2)* (ht**3) )+
							_FLadageRbmi3R    * (adult* (age**(-1))* (bmi**(-3)) )+
							_FLadageht3     	* (adult* age* (ht**3) )+
							_FLadagewt      	* (adult* age* wt )+
							_FLadbmi3R		* (adult* (bmi**(-3)) )+
							_FLage3Rbmi3R    	* ((age**(-3))* (bmi**(-3)) )+
							_FLage3Rwaist3    * ((age**(-3))* (waist**3) )+
							_FLbkbmiR      	* (bk* (bmi**(-1)) )+	
							_FLbmiR        	* (bmi**(-1) )+
							_FLht2R        	* (ht**(-2) )+
							_FLhtR     		* (ht**(-1) )+
							_FLmtbmi3R		* (mt* (bmi**(-3)) )+
							_FLmtwaist3R    	* (mt* (waist**(-3)) )+
							_FLmxbmi2R    	* (mx* (bmi**(-2)) )+
							_FLmxbmi3R     	* (mx* (bmi**(-3)) )+
							_FLwaist2R    	* (waist**(-2) )+
							_FLwaistR			* (waist**(-1) )
							
						;
	run;		

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODL2;
	RUN;
	
	proc sql;
		create table MOD12 as
		select a.predbf_L, a.ID
		from coefModL as a;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODL;
	RUN;

	PROC SORT DATA=MOD12;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD12;
		BY ID;
	RUN;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD12;
	RUN;

	*********
	*Model M;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModM(drop=_name_ _label_) prefix=_MM;
	    id parameter;
	    var MModM;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModM(drop=_name_ _label_) prefix=_FM;
	    id parameter;
	    var FModM;
	run;
	*Merge "M" data sets;
	proc sql;
		create table coefModM2 as
		select m.*, f.*,
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML, t.LEG, t.MENSES,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModM as m, coefFModM as f, &usedata as t;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODM COEFFMODM;
	RUN;

	*Calculate Predicted body fat;
	data coefModM;
		set coefModM2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBF_M= 
						_MMintercept +
						_MMBMI  		* (bmi )+
						_MMadage3RwtR * (adult* (age**(-3))* (wt**(-1)) )+
						_MMadage3ht3R * (adult* (age**3)* (ht**(-3)) )+
						_MMadagebmi  	* (adult* age* bmi )+
						_MMadagetri3  * (adult* age* (tri**3) )+
						_MMadagewt 	* (adult* age* wt )+
						_MMadtri3R    * (adult* (tri**(-3)) )+
						_MMadwt3		* (adult* (wt**3) )+
						_MMage2Rbmi3 	* ((age**(-2))* (bmi**3) )+
						_MMage3Rtri3  * ((age**(-3))* (tri**3) )+  	
						_MMageRht3   	* ((age**(-1))* (ht**3) )+
						_MMageRtri   	* ((age**(-1))* tri )+
						_MMbkbmi   	* (bk* bmi )+
						_MMbkht    	* (bk* ht )+
						_MMbkwt    	* (bk* wt )+  
						_MMbmi2   	* (bmi**2 )+   
						_MMht			* (ht )+
						_MMmtadtri 	* (mt*adult* tri )+   
						_MMmxht3R  	* (mx* (ht**(-3)) )+  
						_MMmxtri3R 	* (mx* (tri**(-3)) )+ 
						_MMmxtriR  	* (mx* (tri**(-1)) )+    
						_MMmxwt3   	* (mx* (wt**3) )+ 
						_MMraceBlack	* (bk )+     
						_MMtri     	* (tri )+
						_MMtri3R   	* (tri**(-3) )+ 
						_MMtriR		* (tri**(-1) )
					
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")  then 

				predBF_M=	
							_FMintercept +
							_FMBMI    		* (bmi )+
							_FMadage2ht2    	* (adult* (age**2)* (ht**2) )+
							_FMadage2ht3   	* (adult* (age**2)* (ht**3) )+
							_FMadage3Rtri3R   * (adult* (age**(-3))* (tri**(-3)) )+
							_FMadage3tri3   	* (adult* (age**3)* (tri**3) )+
							_FMadage3triR		* (adult* (age**3)* (tri**(-1)) )+
							_FMadageRbmi3R    * (adult* (age**(-1))* (bmi**(-3)) )+
							_FMadagewt    	* (adult* age* wt )+
							_FMadbmi3R  		* (adult* (bmi**(-3)) )+
							_FMage2Rtri2  	* ((age**(-2))* (tri**2) )+
							_FMage3Rbmi3R  	* ((age**(-3))* (bmi**(-3)) )+
							_FMage3Rtri2  	* ((age**(-3))* (tri**2) )+
							_FMbkbmiR   		* (bk* (bmi**(-1)) )+
							_FMbkht2R			* (bk* (ht**(-2)) )+
							_FMbkhtR     		* (bk* (ht**(-1)) )+
							_FMbktriR      	* (bk* (tri**(-1)) )+
							_FMbmiR        	* (bmi**(-1) )+
							_FMht2R        	* (ht**(-2) )+
							_FMhtR      		* (ht**(-1) )+
							_FMmxwtR      	* (mx* (wt**(-1)) )+
							_FMtri       		* (tri )+
							_FMtriR			* (tri**(-1) )
							
					;
	run;	

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODM2;
	RUN;
	
	proc sql;
		create table MOD13 as
		select a.predbf_M, a.ID
		from coefModM as A;		
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODM;
	RUN;

	PROC SORT DATA=MOD13;
		BY ID;
	RUN;


	DATA MOD;
		MERGE MOD MOD13;
		BY ID;
	RUN;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD13;
	RUN;




	*********
	*Model N;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModN(drop=_name_ _label_) prefix=_MN;
	    id parameter;
	    var MModN;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModN(drop=_name_ _label_) prefix=_FN;
	    id parameter;
	    var FModN;
	run;
	*Merge "N" data sets;
	proc sql;
		create table coefModN2 as
		select m.*, f.*, t.*, (age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
					(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt
		from coefMModN as m, coefFModN as f, &usedata as t;
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODN COEFFMODN;
	RUN;

	*Calculate Predicted body fat;
	data coefModN;
		set coefModN2;
	
		if upcase(sex)="M" and ethnicity ne "." then

				predBF_N= _MNintercept +
						_MNBMI		* (bmi )+
						_MNadage2Rht3R* (adult* (age**(-2))* (ht**(-3)) )+
						_MNadage3Rht2R* (adult* (age**(-3))* (ht**(-2)) )+
						_MNadage3RhtR * (adult* (age**(-3))* (ht**(-1)) )+
						_MNadage3ht3R * (adult* (age**3)* (ht**(-3)) )+     
						_MNadageRwt2R	* (adult* (age**(-1))* (wt**(-2)) )+
						_MNadageht3   * (adult* age* (ht**3) )+
						_MNadagewt    * (adult* age* wt )+
						_MNadht3   	* (adult* (ht**3) )+
						_MNadwt3R   	* (adult* (wt**(-3)) )+
						_MNage2Rbmi2  * ((age**(-2))* (bmi**2) )+
						_MNage3Rht3R  * ((age**(-3))* (ht**(-3)) )+
						_MNage3Rwt2   * ((age**(-3))* (wt**2) )+
						_MNageRbmi	* ((age**(-1))* bmi )+
						_MNageRbmi2   * ((age**(-1))* (bmi**2) )+
						_MNageRbmi3R  * ((age**(-1))* (bmi**(-3)) )+
						_MNbkadwt3R   * (bk*adult* (wt**(-3)) )+
						_MNbkht3  	* (bk* (ht**3) )+
						_MNbkwtR    	* (bk* (wt**(-1)) )+
						_MNbmiR     	* (bmi**(-1) )+
						_MNht     	* (ht )+
						_MNhtR  		* (ht**(-1) )+
						_MNmtadbmi3R	* (mt*adult* (bmi**(-3)) )+
						_MNmtadht3    * (mt*adult* (ht**3) )+  
						_MNmtwt3R    	* (mt* (wt**(-3)) )+  
						_MNmxadwt3   	* (mx*adult* (wt**3) )+ 
						_MNmxbmi3R    * (mx* (bmi**(-3)) )+  
						_MNmxht3      * (mx* (ht**3) )+    
						_MNmxwt3		* (mx* (wt**3) )
						;

		else if upcase(sex)="F" and ethnicity ne "." then 

				predBF_N=	_FNintercept +
							_FNBMI    		* (bmi )+
							_FNadage2ht3    	* (adult* (age**2)* (ht**3) )+
							_FNadageRbmi3R    * (adult* (age**(-1))* (bmi**(-3)) )+
							_FNadageht3    	* (adult* age* (ht**3) )+
							_FNadagewt   		* (adult* age* wt )+
							_FNage3Rbmi2  	* ((age**(-3))* (bmi**2) )+
							_FNage3Rbmi3		* ((age**(-3))* (bmi**3) )+
							_FNage3Rbmi3R  	* ((age**(-3))* (bmi**(-3)) )+
							_FNage3Rht2R  	* ((age**(-3))* (ht**(-2)) )+
							_FNbkbmi2R  		* (bk* (bmi**(-2)) )+
							_FNbkbmiR  		* (bk* (bmi**(-1)) )+
							_FNbkwtR    		* (bk* (wt**(-1)) )+
							_FNbmiR    		* (bmi**(-1) )+
							_FNht2R   		* (ht**(-2) )+
							_FNmtadbmi3R 		* (mt*adult* (bmi**(-3)) )+
							_FNmxbmi2R		* (mx* (bmi**(-2)) )
							;
	run;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODN2;
	RUN;
	
	proc sql;
		create table MOD14 as
		select a.predbf_N, t.*
		from coefModN as A, &usedata as t
		where a.id = t.id;
	quit;



	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODN2;
	RUN;
	
	proc sql;
		create table MOD14 as
		select a.predbf_N, a.ID
		from coefModN as A;		
	quit;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODM COEFMOD;
	RUN;

	PROC SORT DATA=MOD14;
		BY ID;
	RUN;


	DATA MOD;
		MERGE MOD MOD14;
		BY ID;
	RUN;

	**Delete temporary datasets;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD14;
	RUN;


	DATA MACROLIB.predBFdata;
		MERGE &USEDATA MOD;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD;
	RUN;


data makedata;
		set &usedata(keep=
		%if &chkAge^=0 	%then %do;	age   %end;
		%if &chkHt^=0 	%then %do;	ht    %end;
		%if &chkWt^=0 	%then %do;	wt    %end;
		%if &chkArml^=0 %then %do;	arml  %end;
		%if &chkLeg^=0 	%then %do;	leg   %end;
		%if &chkArmc^=0 %then %do;	armc  %end;
		%if &chkWaist^=0 %then %do; waist %end;
		%if &chkCalf^=0 %then %do;	calf  %end;
		%if &chkThic^=0 %then %do;	thic  %end;
		%if &chkTri^=0 	%then %do;	tri   %end;
		%if &chkSub^=0 	%then %do;	sub   %end;
		);
	run;
	
	proc means data = makedata maxdec=0;
		output out=_a;
	run;
	
	data _a;
		set _a(where=(_STAT_="MEAN"));
		%if &chkAge^=0 	%then %do;	chkAgeUnit = (8<=age<=85); %end;
		%if &chkHt^=0 	%then %do;	chkHtUnit = (127<=ht<=177); %end;
		%if &chkWt^=0 	%then %do;	chkWtUnit = (25<=wt<=106); %end;
		%if &chkArml^=0 %then %do;	chkArmlUnit = (26<=arml<=41); %end;
		%if &chkLeg^=0 	%then %do;	chkLegUnit = (29<=leg<=46); %end;
		%if &chkArmc^=0 %then %do;	chkArmcUnit = (18<=armc<=40); %end;
		%if &chkWaist^=0 %then %do; chkWaistUnit = (55<=waist<=120); %end;
		%if &chkCalf^=0 %then %do;	chkCalfUnit = (25<=calf<=47); %end;
		%if &chkThic^=0 %then %do;	chkThicUnit = (34<=thic<=67); %end;
		%if &chkTri^=0 	%then %do;	chkTriUnit = (7<=tri<=38); %end;
		%if &chkSub^=0 	%then %do;	chkSubUnit = (5<=sub<=38); %end;
	run;

	data _null_;
		set _a;
		call symput('chkAgeUnit', 	chkAgeUnit);
		call symput('chkHtUnit',	chkHtUnit);
		call symput('chkWtUnit',	chkWtUnit);
		call symput('chkArmlUnit',	chkArmlUnit);
		call symput('chkLegUnit',   chkLegUnit);
		call symput('chkArmcUnit', 	chkArmcUnit);
		call symput('chkWaistUnit', chkWaistUnit);
		call symput('chkCalfUnit', 	chkCalfUnit);
		call symput('chkThicUnit', 	chkThicUnit);
		call symput('chkTriUnit', 	chkTriUnit);
		call symput('chkSubUnit', 	chkSubUnit);
	run;

	**Delete temporary datasets;
		PROC DATASETS LIBRARY=WORK NOLIST;
			DELETE _A MAKEDATA;
		RUN;


		%if &chkAgeUnit=0 	%then %put WARNING: Variable AGE is out-of-range [8, 85]. ;
		%if &chkEthnicityUnit=0 	%then %put WARNING: Variable ETHNICITY is out-of-range [W, B, M, O] ;
		%if &chkHtUnit=0 	%then %put WARNING: Variable HT is out-of-range [127, 177].;
		%if &chkWtUnit=0 	%then %put WARNING: Variable WT is out-of-range [25, 106].;
		%if &chkArmlUnit=0 	%then %put WARNING: Variable ARML is out-of-range [26, 41].;
		%if &chkLegUnit=0 	%then %put WARNING: Variable LEG is out-of-range [29, 46].;
		%if &chkArmcUnit=0 	%then %put WARNING: Variable ARMC is out-of-range [18, 40].;
		%if &chkWaistUnit=0 %then %put WARNING: Variable WAIST is out-of-range [55, 120].;
		%if &chkCalfUnit=0 	%then %put WARNING: Variable CALF is out-of-range [25, 47].;
		%if &chkThicUnit=0 	%then %put WARNING: Variable THIC is out-of-range [34, 67].;
		%if &chkTriUnit=0 	%then %put WARNING: Variable TRI is out-of-range [7, 38].;
		%if &chkSubUnit=0 	%then %put WARNING: Variable SUB is out-of-range [5, 38].;
		%if %upcase(sex)=F %then %do;
			%if &chkMensesUnit=0 	%then %put WARNING: Variable MENSES is out-of-range [0, 1] ;
		%end;
%exit:
%mend calcPred;


